@@ -1,7 +1,6 @@
 from pathlib import Path
 from typing import Any, Dict, Iterable, List, Union
 
-import mlflow
 import pandas as pd
 
 from tabml.data_loaders import BaseDataLoader
@@ -51,11 +50,17 @@ class ModelAnalysis:
             Training sample size for the analysis.
     """
 
+    train_dataset_name = "train"
+    val_dataset_name = "val"
+    prediction_filename = "prediction.csv"
+    overall_name = "OVERALL"
+    sample_count_name = "sample_count"
+
     def __init__(
         self,
         data_loader: BaseDataLoader,
         model_wrapper: BaseModelWrapper,
-        params=pipeline_config.ModelAnalysis(),
+        params: pipeline_config.ModelAnalysis,
         output_dir: str = "",
         pred_col: str = "prediction",
         pred_proba_col: str = "prediction_probability",
@@ -64,7 +69,7 @@ class ModelAnalysis:
         self.data_loader = data_loader
         self.model_wrapper = model_wrapper
         self.features_to_analyze = params.by_features
-        self.metrics = _get_metrics(params.metrics)
+        self.metrics = self._get_metrics(params.metrics)
         self.output_dir = output_dir
         self.label_to_analyze = params.by_label or self.data_loader.label_col
         self.pred_col = pred_col
@@ -78,18 +83,21 @@ class ModelAnalysis:
         # True at initialization, then to False right after printing the first overall
         # scores.
         self._show_overall_flag = True
-        self.training_size = params.training_size
+        self.metric_train_size = params.metric_train_size
+        self.explainer_train_size = params.explainer_train_size
 
         self.show_feature_importance = params.show_feature_importance
 
     def analyze(self):
         if self.show_feature_importance:
             self._show_feature_importance()
-        self._analyze_metrics_one_dataset("train")
-        self._analyze_metrics_one_dataset("val")
+        self._analyze_metrics_one_dataset(self.train_dataset_name)
+        self._analyze_metrics_one_dataset(self.val_dataset_name)
 
     def _show_feature_importance(self):
-        train_feature = self._get_dataset("train")[self.data_loader.features]
+        train_feature = self._get_dataset(self.train_dataset_name)[
+            self.data_loader.features
+        ]
         feature_importance_dict = self.model_wrapper.get_feature_importance(
             train_feature
         )
@@ -97,33 +105,42 @@ class ModelAnalysis:
 
     def _analyze_metrics_one_dataset(self, dataset_name: str):
         self._show_overall_flag = True
-        dataset = self._get_dataset(dataset_name)
+        dataset = self._get_dataset(dataset_name, dataset_size=self.metric_train_size)
         preds = self._get_predictions(dataset)
         df_with_pred = self._get_df_with_pred(dataset, dataset_name, preds)
         for feature_name in self.features_to_analyze:
             self._analyze_on_feature(df_with_pred, feature_name, dataset_name)
 
-    def _get_dataset(self, dataset_name: str):
+    def _get_dataset(
+        self, dataset_name: str, dataset_size: Union[int, float, None] = None
+    ):
         all_features = (
             list(self.features_to_analyze)
             + self.data_loader.features
             + [self.label_to_analyze]
         )
         all_features = list(set(all_features))
-        if dataset_name == "train":
+        if dataset_name == self.train_dataset_name:
             df = self.data_loader.feature_manager.extract_dataframe(
                 features_to_select=all_features, filters=self.data_loader.train_filters
             )
-            if self.training_size:
-                return df.sample(n=min(int(self.training_size), len(df)))
+            if dataset_size is not None:
+                if isinstance(dataset_size, int):
+                    num_samples = dataset_size
+                else:  # float
+                    num_samples = int(dataset_size * len(df))
+                return df.sample(n=min(num_samples, len(df)))
             return df
 
-        if dataset_name == "val":
+        if dataset_name == self.val_dataset_name:
             return self.data_loader.feature_manager.extract_dataframe(
                 features_to_select=all_features,
                 filters=self.data_loader.validation_filters,
             )
-        raise ValueError(f"dataset_name ({dataset_name}) not in ('train', 'val')")
+        raise ValueError(
+            f"dataset_name ({dataset_name}) not in "
+            f"('{self.train_dataset_name}', '{self.val_dataset_name}')"
+        )
 
     def _get_predictions(self, dataset) -> Dict[str, Iterable]:
         res = {}
@@ -159,7 +176,9 @@ class ModelAnalysis:
             for feature_value, group in df_with_pred.groupby(feature_name)
         ]
         # add overall score
-        overall_scores = self._get_metric_dict(feature_name, "OVERALL", df_with_pred)
+        overall_scores = self._get_metric_dict(
+            feature_name, self.overall_name, df_with_pred
+        )
         list_of_group_dicts.append(overall_scores)
         if self._show_overall_flag:
             self._show_and_log_overall_scores(overall_scores, dataset_name)
@@ -180,7 +199,7 @@ class ModelAnalysis:
     ) -> Dict[str, Union[str, float]]:
         labels = df_with_pred[self.label_to_analyze]
 
-        res = {feature_name: feature_value, "sample_count": len(df_with_pred)}
+        res = {feature_name: feature_value, self.sample_count_name: len(df_with_pred)}
         for metric in self.metrics:
             if metric.need_pred_proba:
                 res.update(
@@ -194,7 +213,7 @@ class ModelAnalysis:
         dirname = Path(self.output_dir) / dataset_name
         if not dirname.exists():
             dirname.mkdir()
-        return Path(self.output_dir) / dataset_name / "prediction.csv"
+        return Path(self.output_dir) / dataset_name / self.prediction_filename
 
     def _get_df_feature_metric_csv_path(self, dataset_name: str, col: str):
         dirname = Path(self.output_dir) / dataset_name
@@ -206,12 +225,11 @@ class ModelAnalysis:
         logger.info("=" * 20 + f" OVERALL SCORES on {dataset_name} dataset " + "=" * 20)
         logger.info("{:<20}: {}".format("Num samples", overall_scores["sample_count"]))
         for key, val in overall_scores.items():
-            if val == "OVERALL" or key == "sample_count":
+            if val == self.overall_name or key == self.sample_count_name:
                 continue
             logger.info("{:<20}: {}".format(key, val))
-            mlflow.log_metrics({key: val})
 
-
-def _get_metrics(metric_names: List[str]) -> List[BaseMetric]:
-    metric_by_name = get_instantiated_metric_dict()
-    return [metric_by_name[metric_name] for metric_name in metric_names]
+    @staticmethod
+    def _get_metrics(metric_names: List[str]) -> List[BaseMetric]:
+        metric_by_name = get_instantiated_metric_dict()
+        return [metric_by_name[metric_name] for metric_name in metric_names]
