@@ -2,7 +2,6 @@ from abc import ABC, abstractmethod
 from pathlib import Path
 from typing import Dict, Iterable, Tuple, Union
 
-import mlflow
 import numpy as np
 import shap
 from catboost import CatBoostClassifier, CatBoostRegressor
@@ -14,14 +13,7 @@ from tabml.schemas import pipeline_config
 from tabml.schemas.pipeline_config import ModelBundle
 from tabml.utils import factory, utils
 from tabml.utils.logger import boosting_logger_eval
-from tabml.utils.utils import load_pickle, save_as_pickle
-
-MLFLOW_AUTOLOG = {
-    "sklearn": mlflow.sklearn.autolog(),
-    "lightgbm": mlflow.lightgbm.autolog(),
-    "xgboost": mlflow.xgboost.autolog(),
-    "catboost": None,
-}
+from tabml.utils.utils import load_pickle
 
 
 class BaseModelWrapper(ABC):
@@ -106,7 +98,6 @@ class BaseSklearnModelWrapper(BaseModelWrapper):
         train_feature, train_label = data_loader.get_train_data_and_label()
 
         self.model.fit(X=train_feature, y=train_label, **self.fit_params)
-        save_as_pickle(self.model, model_dir, self.save_model_name)
 
     def load_model(self, model_path: Union[str, Path]):
         self.model = utils.load_pickle(model_path)
@@ -146,7 +137,6 @@ class BaseBoostingModelWrapper(BaseModelWrapper):
         fit_params = self._get_fit_params((train_feature, train_label), val_data)
 
         self.model.fit(X=train_feature, y=train_label, **fit_params)
-        save_as_pickle(self.model, model_dir, self.save_model_name)
 
 
 class BaseLgbmModelWrapper(BaseBoostingModelWrapper):
@@ -198,9 +188,9 @@ class BaseXGBoostModelWrapper(BaseBoostingModelWrapper):
         self.model = utils.load_pickle(model_path)
 
     def _get_fit_params(self, train_data, val_data):
+        # TODO: add callback to display train and validation metrics
         fit_params = {
             "eval_set": [train_data, val_data],
-            "callbacks": [boosting_logger_eval(model="xgboost")],
             **self.fit_params,
         }
         return fit_params
