@@ -38,6 +38,13 @@ class ModelAnalysis(pydantic.BaseModel):
     # for backward compatibility.
     show_feature_importance: bool = True
 
+    # How many datapoints used for running explainer.
+    # Only used when show_feature_importance = True
+    # int: number of datapoints
+    # float: must be a number in (0, 1]
+    # None: all datapoints
+    explainer_train_size: Union[int, float, None] = None
+
     # list of features for analysis
     by_features: List[str] = []
 
@@ -46,10 +53,23 @@ class ModelAnalysis(pydantic.BaseModel):
     # original label.
     by_label: Union[str, None] = None
 
-    # To avoid expensive computations, e.g. computing SHAP values or inference,
-    # a subset of training data could be used instead. This field specifies size
-    # of that subset.
-    training_size: Union[int, None] = None
+    # To avoid expensive computations, a subset of training data could be used instead.
+    # This field specifies the subset size. Usage is similar to explainer_train_size.
+    metric_train_size: Union[int, float, None] = None
+
+    @pydantic.validator("explainer_train_size")
+    def validate_float_explainer_train_size(cls, v):
+        if isinstance(v, float) and (v <= 0 or v >= 1):
+            raise ValueError(
+                "When explainer_train_size is a float, it must be in (0, 1)."
+            )
+        return v.title()
+
+    @pydantic.validator("metric_train_size")
+    def validate_float_metric_train_size(cls, v):
+        if isinstance(v, float) and (v <= 0 or v >= 1):
+            raise ValueError("When metric_train_size is a float, it must be in (0, 1).")
+        return v.title()
 
 
 class PipelineConfig(pydantic.BaseModel):
